@@ -30,7 +30,7 @@ swmpr <- function(stat_in, meta_in){
   param_types <- unlist(lapply(param_types, function(x) any(x %in% parameters)))
   param_types <- names(param_names())[param_types]
   station <- grep(paste0(param_types, collapse = '|'), meta_in, value = TRUE)
-  
+
   # timezone using time_vec function
   timezone <- time_vec(station_code = station, tz_only = TRUE)
 
@@ -67,9 +67,9 @@ swmpr <- function(stat_in, meta_in){
 #' 
 #' @return Returns a \code{data.frame} of parsed XML nodes
 parser <- function(resp_in, parent_in = 'data'){
-  
+
   # convert to XMLDocumentContent for parsing
-  raw <- htmlTreeParse(resp_in, useInternalNodes = TRUE)
+  raw <- xmlTreeParse(resp_in, useInternalNodes = TRUE)
 
   # get parent data nodes
   parents <- xpathSApply(
@@ -83,6 +83,7 @@ parser <- function(resp_in, parent_in = 'data'){
     )
   out <- do.call('rbind', out)
   out <- data.frame(out)
+  names(out) <- tolower(names(out))
   
   # return output
   return(out)
@@ -475,3 +476,6 @@ calckl <- function(temp, sal, atemp, wspd, bp, height = 10){
   return(KL)
   
   }
+
+#' @importFrom stats var
+NULL
\ No newline at end of file
